@@ -1,11 +1,12 @@
+from typing import List
+
 from sqlalchemy import create_engine, inspect, MetaData
 from sqlalchemy.ext.automap import automap_base
-from typing import List
 
 from pkg.tool.convert import to_upper_camel_case, dict2params_str
 
 
-def sqlacodegen(url, schemas=None, table_names=None, file=None):
+def sqlacodegen(url, schemas=None, table_names=None, file=None, ignore=False):
     packages = {
         "sqlalchemy.ext.declarative": ["declarative_base"],
         "sqlalchemy": ["Column"]
@@ -44,9 +45,10 @@ def sqlacodegen(url, schemas=None, table_names=None, file=None):
                     db_table_info_map[t.schema][t.name] = dict()
                 if "table_args" not in db_table_info_map[t.schema][t.name]:
                     db_table_info_map[t.schema][t.name]["table_args"] = {
-                        "schema": t.schema,
                         "comment": t.comment
                     }
+                    if not ignore:
+                        db_table_info_map[t.schema][t.name]["table_args"]["schema"] = t.schema
                     # if t.indexes:
                     #     db_table_info_map[t.schema][t.name]["table_args"]["indexes"] = set()
                     #     for index in t.indexes:
@@ -102,8 +104,10 @@ def sqlacodegen(url, schemas=None, table_names=None, file=None):
                             if "foreign_key" not in db_table_info_map[t.schema][child_table]:
                                 db_table_info_map[t.schema][child_table]["foreign_key"] = dict()
                             if child_field not in db_table_info_map[t.schema][child_table]:
+                                foreign_key_column = fr'{parent_table}.{parent_field}' if ignore else \
+                                    fr'{parent_db}.{parent_table}.{parent_field}'
                                 foreign_key_params = {
-                                    "column": fr'{parent_db}.{parent_table}.{parent_field}'
+                                    "column": foreign_key_column
                                 }
                                 if foreign_key.use_alter is not None:
                                     foreign_key_params.update({
@@ -129,7 +133,8 @@ def sqlacodegen(url, schemas=None, table_names=None, file=None):
     for db, db_indo in db_table_info_map.items():
         for table, table_info in db_indo.items():
             table_info["columns"]: List[dict] = isp.get_columns(table, schema=db)
-            class_class_name_str = f"""\n\nclass {to_upper_camel_case(table)}(Base):"""
+            table_name = f"{db}_{table}" if not ignore else table
+            class_class_name_str = f"""\n\nclass {to_upper_camel_case(table_name)}(Base):"""
             table_args = table_info.get("table_args", {})
             table_args_str = ""
             if table_args:
@@ -144,11 +149,15 @@ def sqlacodegen(url, schemas=None, table_names=None, file=None):
             relationship = db_table_info_map.get(db, {}).get(table, {}).get("relationship", {})
             if relationship:
                 for child_table, relationship_info in relationship.items():
-                    # child_db = relationship_info.get("child_db")
+                    child_db = relationship_info.get("child_db")
+                    parent_db = relationship_info.get("parent_db")
+                    parent_table = relationship_info.get("parent_table")
+                    relation_table = f"{child_db}_{child_table}" if not ignore else child_table
+                    self_table = f"{parent_db}_{parent_table}" if not ignore else parent_table
                     table_info["columns"].append(
-                        {f'{child_table}': f"relationship('{to_upper_camel_case(child_table)}',"
-                                           f" backref='{child_table}')",
-                         "name": f'{child_table}', "is_relation_field": True})
+                        {f'{relation_table}': f"relationship('{to_upper_camel_case(relation_table)}',"
+                                              f" backref='{self_table}')",
+                         "name": f'{relation_table}', "is_relation_field": True})
 
             for column in table_info["columns"]:
                 if 'foreign_key' in db_table_info_map[db][table]:
